import "Turbine";
import "Turbine.Debug";
import "Turbine.Gameplay";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "DhorPlugins.Extensions";
import "DhorPlugins.Utils.BitOps";

OptionsWindow = class(Turbine.UI.Lotro.Window);

function OptionsWindow:Constructor(parent)
	Turbine.UI.Lotro.Window.Constructor( self );
   
   --  add a check to see if we load completely
   self.loaded = false;
    
   -- set size of window	
	self.width = 500;
	self.height = 500;
	self.windowWidth, self.windowHeight = Turbine.UI.Display:GetSize();
	
	-- create link to parent window
	self.mainWindow = parent;
   
	-- set the default window settings
	self:SetPosition(self.windowWidth /2 - self.width/2,self.windowHeight/2 - self.height/2);	
	self:SetSize( self.width, self.height );
	self:SetBlendMode(Turbine.UI.BlendMode.Undefined);
	self:SetBackColor( Turbine.UI.Color(0.0,0,0,0) );
	self:SetText( optionsTitleString );
	self:SetOpacity( 1 );
	
	-- add the option items
   
   self:AddGeneralItems();
	self:SetVisible(true);
	
	-- have the main window close the options
   self.VisibleChanged = function(sender,args)
      if(self:IsVisible() == false) then
         if(parent ~= nil) then
            parent:CloseOptions();
         end
      end
   end
      
   self.loaded = true;	
end

function OptionsWindow:GetLoaded()
   return self.loaded;
end

-- function to add items to the general tab
function OptionsWindow:AddGeneralItems()

   -- label for the horizontal option
   self.HorizontalLabel = Turbine.UI.Label();
   self.HorizontalLabel:SetSize(300,20);
   self.HorizontalLabel:SetPosition(20,40);
   self.HorizontalLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.HorizontalLabel:SetParent(self);
   self.HorizontalLabel:SetText(horizontalString);
   self.HorizontalLabel:SetVisible(true);
   
   -- checkbox for horizontal option
   self.HorizontalCheck = Turbine.UI.Lotro.CheckBox();   
   self.HorizontalCheck:SetSize(19,19);
   self.HorizontalCheck:SetPosition(450,40);
   self.HorizontalCheck:SetChecked(settings.horizontal == 1);
   self.HorizontalCheck:SetParent(self);
   self.HorizontalCheck:SetVisible(true); 

   -- label for the lock option
   self.BarsLabel = Turbine.UI.Label();
   self.BarsLabel:SetSize(300,20);
   self.BarsLabel:SetPosition(20,70);
   self.BarsLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.BarsLabel:SetParent(self);
   self.BarsLabel:SetText(showBarsString);
   self.BarsLabel:SetVisible(true);
   
   -- checkbox for lock option
   self.BarsCheck = Turbine.UI.Lotro.CheckBox();   
   self.BarsCheck:SetSize(19,19);
   self.BarsCheck:SetPosition(450,70);
   self.BarsCheck:SetChecked(settings.showBars == 1);
   self.BarsCheck:SetParent(self);
   self.BarsCheck:SetVisible(true); 

   -- label for the show bars option
   self.NumberLabel = Turbine.UI.Label();
   self.NumberLabel:SetSize(300,20);
   self.NumberLabel:SetPosition(20,100);
   self.NumberLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.NumberLabel:SetParent(self);
   self.NumberLabel:SetText(showNumberString);
   self.NumberLabel:SetVisible(true);
   
   -- checkbox for show bars option
   self.NumberCheck = Turbine.UI.Lotro.CheckBox();   
   self.NumberCheck:SetSize(19,19);
   self.NumberCheck:SetPosition(450,100);
   self.NumberCheck:SetChecked(settings.showNumber == 1);
   self.NumberCheck:SetParent(self);
   self.NumberCheck:SetVisible(true); 

   -- label for the show number option
   self.LockLabel = Turbine.UI.Label();
   self.LockLabel:SetSize(300,20);
   self.LockLabel:SetPosition(20,130);
   self.LockLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.LockLabel:SetParent(self);
   self.LockLabel:SetText(lockString);
   self.LockLabel:SetVisible(true);
   
   -- checkbox for show number option
   self.LockCheck = Turbine.UI.Lotro.CheckBox();   
   self.LockCheck:SetSize(19,19);
   self.LockCheck:SetPosition(450,130);
   self.LockCheck:SetChecked(settings.lock == 1);
   self.LockCheck:SetParent(self);
   self.LockCheck:SetVisible(true);   

   -- label for custom skin option
   self.SkinLabel = Turbine.UI.Label();
   self.SkinLabel:SetSize(300,20);
   self.SkinLabel:SetPosition(20,160);
   self.SkinLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.SkinLabel:SetParent(self);
   self.SkinLabel:SetText(skinString);
   self.SkinLabel:SetVisible(true);
   
   -- checkbox for custom skin option
   self.SkinCheck = Turbine.UI.Lotro.CheckBox();   
   self.SkinCheck:SetSize(19,19);
   self.SkinCheck:SetPosition(450,160);
   self.SkinCheck:SetChecked(settings.skin == 1);
   self.SkinCheck:SetParent(self);
   self.SkinCheck:SetVisible(true);   
        
   --[[ Color Selections ]]--
   
   -- label for the back color selection
   self.BackColorLabel = Turbine.UI.Label();
   self.BackColorLabel:SetSize(300,20);
   self.BackColorLabel:SetPosition(20,212);
   self.BackColorLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.BackColorLabel:SetParent(self);
   self.BackColorLabel:SetText(backColorString);
   self.BackColorLabel:SetVisible(true);
   
   -- 'box' for the back color selection
   self.BackColorBox = Turbine.UI.Label();
   self.BackColorBox:SetSize(50,20);
   self.BackColorBox:SetPosition(420,210);
   self.BackColorBox:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.BackColorBox:SetParent(self);
   self.BackColorBox:SetBackColor(settings.backColor);
   self.BackColorBox:SetVisible(true);
   
   -- label for the number color selection
   self.NumberColorLabel = Turbine.UI.Label();
   self.NumberColorLabel:SetSize(300,20);
   self.NumberColorLabel:SetPosition(20,242);
   self.NumberColorLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.NumberColorLabel:SetParent(self);
   self.NumberColorLabel:SetText(textColorString);
   self.NumberColorLabel:SetVisible(true);
   
   -- 'box' for the number color selection
   self.NumberColorBox = Turbine.UI.Label();
   self.NumberColorBox:SetSize(50,20);
   self.NumberColorBox:SetPosition(420,240);
   self.NumberColorBox:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.NumberColorBox:SetParent(self);
   self.NumberColorBox:SetBackColor(settings.numberColor);
   self.NumberColorBox:SetVisible(true);
     
   -- label for the fervour color selection
   self.FervourColorLabel = Turbine.UI.Label();
   self.FervourColorLabel:SetSize(400,20);
   self.FervourColorLabel:SetPosition(20,272);
   self.FervourColorLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.FervourColorLabel:SetParent(self);
   self.FervourColorLabel:SetText(fervourColorString);
   self.FervourColorLabel:SetVisible(true);
   
   -- 'box' for the fervour color selection
   self.FervourColorBox = Turbine.UI.Label();
   self.FervourColorBox:SetSize(50,20);
   self.FervourColorBox:SetPosition(420,270);
   self.FervourColorBox:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.FervourColorBox:SetParent(self);
   self.FervourColorBox:SetBackColor(settings.fervourColor);
   self.FervourColorBox:SetZOrder(100);
   self.FervourColorBox:SetVisible(true);
     
   -- label for the strength fervour color selection
   self.FervourAColorLabel = Turbine.UI.Label();
   self.FervourAColorLabel:SetSize(400,20);
   self.FervourAColorLabel:SetPosition(20,302);
   self.FervourAColorLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.FervourAColorLabel:SetParent(self);
   self.FervourAColorLabel:SetText(fervourAColorString);
   self.FervourAColorLabel:SetVisible(true);
   
   -- 'box' for the strength fervour color selection
   self.FervourAColorBox = Turbine.UI.Label();
   self.FervourAColorBox:SetSize(50,20);
   self.FervourAColorBox:SetPosition(420,300);
   self.FervourAColorBox:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.FervourAColorBox:SetParent(self);
   self.FervourAColorBox:SetBackColor(settings.fervourAColor);
   self.FervourAColorBox:SetZOrder(100);
   self.FervourAColorBox:SetVisible(true);
     
   -- label for the precision fervour color selection
   self.FervourFColorLabel = Turbine.UI.Label();
   self.FervourFColorLabel:SetSize(400,20);
   self.FervourFColorLabel:SetPosition(20,332);
   self.FervourFColorLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.FervourFColorLabel:SetParent(self);
   self.FervourFColorLabel:SetText(fervourFColorString);
   self.FervourFColorLabel:SetVisible(true);
   
   -- 'box' for the precision fervour color selection
   self.FervourFColorBox = Turbine.UI.Label();
   self.FervourFColorBox:SetSize(50,20);
   self.FervourFColorBox:SetPosition(420,330);
   self.FervourFColorBox:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.FervourFColorBox:SetParent(self);
   self.FervourFColorBox:SetBackColor(settings.fervourFColor);
   self.FervourFColorBox:SetZOrder(100);
   self.FervourFColorBox:SetVisible(true);
     
   -- label for the fervour color selection
   self.FervourGColorLabel = Turbine.UI.Label();
   self.FervourGColorLabel:SetSize(400,20);
   self.FervourGColorLabel:SetPosition(20,362);
   self.FervourGColorLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.FervourGColorLabel:SetParent(self);
   self.FervourGColorLabel:SetText(fervourGColorString);
   self.FervourGColorLabel:SetVisible(true);
   
   -- 'box' for the fervour color selection
   self.FervourGColorBox = Turbine.UI.Label();
   self.FervourGColorBox:SetSize(50,20);
   self.FervourGColorBox:SetPosition(420,360);
   self.FervourGColorBox:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.FervourGColorBox:SetParent(self);
   self.FervourGColorBox:SetBackColor(settings.fervourGColor);
   self.FervourGColorBox:SetZOrder(100);
   self.FervourGColorBox:SetVisible(true);  
   
   --[[ Opacity Sliders ]]--  
    
   -- label for main window sliders
   self.SlidersLabel  = Turbine.UI.Label();
   self.SlidersLabel:SetSize(300,20);
   self.SlidersLabel:SetPosition(20,410);
   self.SlidersLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.SlidersLabel:SetParent(self);
   self.SlidersLabel:SetText(mainSlidersString);
   self.SlidersLabel:SetVisible(true);
     
   -- main window min slider label
   self.mainMinSlidersLabel  = Turbine.UI.Label();
   self.mainMinSlidersLabel:SetSize(50,30);
   self.mainMinSlidersLabel:SetPosition(20,430);
   self.mainMinSlidersLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.mainMinSlidersLabel:SetParent(self);
   self.mainMinSlidersLabel:SetText(minString);
   self.mainMinSlidersLabel:SetVisible(true);  
   
   -- toggle button min slider		
	self.mainMinScrollBar = Turbine.UI.Lotro.ScrollBar();
	self.mainMinScrollBar:SetOrientation( Turbine.UI.Orientation.Horizontal );	
	self.mainMinScrollBar:SetSize( 400, 10 );
	self.mainMinScrollBar:SetPosition ( 70, 440);	
	self.mainMinScrollBar:SetMinimum(0);
	self.mainMinScrollBar:SetMaximum(100);
	self.mainMinScrollBar:SetValue(settings.mainMinOpacity * 100);
	self.mainMinScrollBar:SetParent(self);

   -- toggle button max slider
   self.mainMaxSlidersLabel  = Turbine.UI.Label();
   self.mainMaxSlidersLabel:SetSize(50,30);
   self.mainMaxSlidersLabel:SetPosition(20,460);
   self.mainMaxSlidersLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.mainMaxSlidersLabel:SetParent(self);
   self.mainMaxSlidersLabel:SetText(maxString);
   self.mainMaxSlidersLabel:SetVisible(true); 
 
   -- toggle button max slider		
	self.mainMaxScrollBar = Turbine.UI.Lotro.ScrollBar();
	self.mainMaxScrollBar:SetOrientation( Turbine.UI.Orientation.Horizontal );	
	self.mainMaxScrollBar:SetSize( 400, 10 );
	self.mainMaxScrollBar:SetPosition ( 70, 470);	
	self.mainMaxScrollBar:SetMinimum(0);
	self.mainMaxScrollBar:SetMaximum(100);
   self.mainMaxScrollBar:SetValue(settings.mainMaxOpacity * 100);
   self.mainMaxScrollBar:SetParent(self);


   --[[ EVENT HANDLERS ]]--
   
   -- set the horizontal option
   self.HorizontalCheck.CheckedChanged = function(sender,args)
      if(sender:IsChecked()) then
         settings.horizontal = 1;
      else
         settings.horizontal = 0;
      end
      self.mainWindow:UpdateLabels();
		self.mainWindow:SaveSettings();
   end 
   
   -- set the lock option
   self.NumberCheck.CheckedChanged = function(sender,args)
      if(sender:IsChecked()) then
         settings.showNumber = 1;
      else
         settings.showNumber = 0;
      end                       
		self.mainWindow:SaveSettings();
      self.mainWindow:UpdateLabels();
   end 
   
   -- set the lock option
   self.BarsCheck.CheckedChanged = function(sender,args)
      if(sender:IsChecked()) then
         settings.showBars = 1;
      else
         settings.showBars = 0;
      end
		self.mainWindow:SaveSettings();
      self.mainWindow:UpdateLabels();
      --self.mainWindow:UpdateFervour();
   end 
   
   -- set the lock option
   self.LockCheck.CheckedChanged = function(sender,args)
      if(sender:IsChecked()) then
         settings.lock = 1;
      else
         settings.lock = 0;
      end
      self.mainWindow:UpdateLabels();
		self.mainWindow:SaveSettings();
   end
   
   -- set the skin option
   self.SkinCheck.CheckedChanged = function(sender,args)
      if(sender:IsChecked()) then
         settings.skin = 1;
      else
         settings.skin = 0;
      end
      self.mainWindow:UpdateLabels();
		self.mainWindow:SaveSettings();
   end
      
   -- call the picker when color box clicked
   self.FervourColorBox.MouseUp = function(sender,args)
      self.colorSelect = DhorPlugins.ChampionFervour.ColorPicker(self,0,settings.fervourColor);    
   end
   
   self.BackColorBox.MouseUp = function(sender,args)
      self.colorSelect = DhorPlugins.ChampionFervour.ColorPicker(self,1,settings.backColor);    
   end
   
   self.FervourAColorBox.MouseUp = function(sender,args)
      self.colorSelect = DhorPlugins.ChampionFervour.ColorPicker(self,2,settings.fervourAColor);    
   end
   
   self.FervourFColorBox.MouseUp = function(sender,args)
      self.colorSelect = DhorPlugins.ChampionFervour.ColorPicker(self,3,settings.fervourFColor);    
   end
   
   self.FervourGColorBox.MouseUp = function(sender,args)
      self.colorSelect = DhorPlugins.ChampionFervour.ColorPicker(self,4,settings.fervourGColor);    
   end
    
   self.NumberColorBox.MouseUp = function(sender,args)
      self.colorSelect = DhorPlugins.ChampionFervour.ColorPicker(self,5,settings.numberColor);    
   end
   
   -- update settings when sliders change
   self.mainMinScrollBar.ValueChanged = function(sender,args)  
      settings.mainMinOpacity = self.mainMinScrollBar:GetValue() / 100;
      self.mainWindow:SaveSettings();
      self.mainWindow:UpdateOpacity();
   end
   
   self.mainMaxScrollBar.ValueChanged = function(sender,args)   
      settings.mainMaxOpacity = self.mainMaxScrollBar:GetValue() / 100;
      self.mainWindow:SaveSettings();
      self.mainWindow:UpdateOpacity();
   end 
end

function OptionsWindow:setFervourColor(newColor)
    settings.fervourColor = Turbine.UI.Color(1,newColor.R,newColor.G,newColor.B);    
end

function OptionsWindow:setFervourAColor(newColor)
    settings.FervourAColor = Turbine.UI.Color(1,newColor.R,newColor.G,newColor.B);    
end

function OptionsWindow:setFervourFColor(newColor)
    settings.FervourFColor = Turbine.UI.Color(1,newColor.R,newColor.G,newColor.B);    
end

function OptionsWindow:setFervourGColor(newColor)
    settings.FervourGColor = Turbine.UI.Color(1,newColor.R,newColor.G,newColor.B);    
end

function OptionsWindow:setBackColor(newColor)
    settings.backColor = Turbine.UI.Color(1,newColor.R,newColor.G,newColor.B);    
end

function OptionsWindow:setNumberColor(newColor)
    settings.numberColor = Turbine.UI.Color(1,newColor.R,newColor.G,newColor.B);    
end

function OptionsWindow:CloseColorPicker()

   self.colorSelect = nil;
   self.FervourColorBox:SetBackColor(settings.fervourColor);
   self.FervourAColorBox:SetBackColor(settings.fervourAColor);
   self.FervourFColorBox:SetBackColor(settings.fervourFColor);
   self.FervourGColorBox:SetBackColor(settings.fervourGColor);
   self.BackColorBox:SetBackColor(settings.backColor);
   self.NumberColorBox:SetBackColor(settings.numberColor);
   self.mainWindow:SaveSettings();
   self.mainWindow:UpdateLabels();
   self.mainWindow:UpdateColors();
end

